@@ -18,16 +18,17 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *******************************************************************/
 
-#ifndef KNOTECONFIGDLG_H
-#define KNOTECONFIGDLG_H
+#ifndef KNOTECONFIGDIALOG_H
+#define KNOTECONFIGDIALOG_H
 
-#include <kconfigdialog.h>
-#include <kcmodule.h>
-#include <kcmultidialog.h>
 #include "knotes_export.h"
 
-class KNotePrintSelectThemeComboBox;
+#include <KCModule>
+#include <KCMultiDialog>
+
 class KNoteCollectionConfigWidget;
+class KNotePrintSelectThemeComboBox;
+
 class QLineEdit;
 
 class KNOTES_EXPORT KNoteConfigDialog : public KCMultiDialog
@@ -73,7 +74,7 @@ public:
 private Q_SLOTS:
     void slotHelpLinkClicked(const QString &);
 private:
-    QLineEdit *mDefaultTitle;
+    QLineEdit *mDefaultTitle = nullptr;
 };
 
 class KNotePrintConfig : public KCModule
@@ -91,7 +92,7 @@ private Q_SLOTS:
     void slotDownloadNewThemes();
 
 private:
-    KNotePrintSelectThemeComboBox *mSelectTheme;
+    KNotePrintSelectThemeComboBox *mSelectTheme = nullptr;
 };
 
 class KNoteCollectionConfig : public KCModule
@@ -104,7 +105,7 @@ public:
     void save() override;
 
 private:
-    KNoteCollectionConfigWidget *mCollectionConfigWidget;
+    KNoteCollectionConfigWidget *mCollectionConfigWidget = nullptr;
 };
 
 #endif
