@@ -26,14 +26,14 @@
 #include "knotesglobalconfig.h"
 #include <KCalUtils/ICalDrag>
 #include <KCalUtils/VCalDrag>
-#include <KCalCore/FileStorage>
+#include <KCalendarCore/FileStorage>
 
 #include "knotes-version.h"
 
 #include <Libkdepim/MaillistDrag>
 using namespace KPIM;
 using namespace KCalUtils;
-using namespace KCalCore;
+using namespace KCalendarCore;
 
 #include <KContacts/VCardDrag>
 
@@ -153,15 +153,15 @@ void KNotesPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (KCalUtils::ICalDrag::canDecode(md)) {
-        KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+        KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         if (KCalUtils::ICalDrag::fromMimeData(md, cal)) {
-            KCalCore::Incidence::List incidences = cal->incidences();
+            KCalendarCore::Incidence::List incidences = cal->incidences();
             Q_ASSERT(incidences.count());
             if (!incidences.isEmpty()) {
                 event->accept();
-                KCalCore::Incidence::Ptr i = incidences.first();
+                KCalendarCore::Incidence::Ptr i = incidences.first();
                 QString summary;
-                if (i->type() == KCalCore::Incidence::TypeJournal) {
+                if (i->type() == KCalendarCore::Incidence::TypeJournal) {
                     summary = i18nc("@item", "Note: %1", i->summary());
                 } else {
                     summary = i->summary();
